# Generated by Django 3.1.6 on 2021-02-06 23:13

from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion

from django.contrib.auth import get_user_model


def connect_onboarding(apps, schema_editor):
    # Create a new Onboarding object for every user
    user_app, user_model = settings.AUTH_USER_MODEL.split(".", 2)
    User = apps.get_model(user_app, user_model)
    Onboarding = apps.get_model("wagtail_onboarding", "Onboarding")
    for user in User.objects.all():
        onboarding = Onboarding.objects.create(user=user)


def disconnect_onboarding(apps, schema_editor):
    # Remove all Onboarding objects so we don't end up with duplicate rows
    # If the migration is reversed
    Onboarding = apps.get_model("wagtail_onboarding", "Onboarding")
    Onboarding.objects.all().delete()


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="Onboarding",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "progress",
                    models.PositiveSmallIntegerField(
                        default=0,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(100),
                        ],
                    ),
                ),
                ("completed_admin_tour", models.BooleanField(default=False)),
                ("completed_page_edit_tour", models.BooleanField(default=False)),
                (
                    "user",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "verbose_name": "Onboarding status",
                "verbose_name_plural": "Onboarding status",
            },
        ),
        migrations.RunPython(connect_onboarding, disconnect_onboarding),
    ]
